# Emily J King
# http://www.math.uni-bremen.de/cda/
# This work is licensed under the Creative Commons Attribution-ShareAlike 4.0 In- ternational License. To view a copy of this license, visit http://creativecommons. org/licenses/by-sa/4.0/ or send a letter to Creative Commons, PO Box 1866, Mountain View, CA 94042, USA.

import matplotlib.pyplot as plt
import numpy as np


plt.figure(1)

ax=plt.gca()
ax.grid('off')

def func(x):
    return -0.5*(x-3)*(x-4)*(x-7)*(x-8.5)*(x-1.5)

a, b = 2, 8 #limits of integration
x = np.hstack((np.arange(3, 4, 0.01),np.arange(7,8.505,0.01)))
y = func(x)
plt.plot(x, y, linewidth=1,color='black')

ax.spines['bottom'].set_bounds(-0.5,10.4)
ax.spines['left'].set_position('zero')
ax.spines['left'].set_bounds(-40,40)
ax.spines['bottom'].set_position('zero')
ax.spines['top'].set_color('none')
ax.spines['right'].set_color('none')
plt.axis([-0.5,10.4, -40, 40])

ax.get_xaxis().tick_bottom()
ax.get_yaxis().tick_left()
ax.set_xticklabels((r'$a$',r'$t_1$',r'$t_2$',r'$t_3$',r'$t_4$',r'$t_5$',r'$b$'),fontsize=16,verticalalignment='baseline',y=-10)
ax.set_xticks(np.arange(a,b+1))
ax.yaxis.set_major_locator(plt.NullLocator())

# Plotting step functions
eps=0.12

# psi
pts = np.array([0,0,0,0,0,0])
for k in np.arange(1,7):
   plt.plot(np.linspace(a+k-1+eps,a+k-eps),np.full((50,1),pts[k-1]),'r',linewidth=2), plt.plot(a+k,pts[k-1],'o',ms=10,color='r'), plt.plot(a+k-1,pts[k-1],'o',ms=10,color='r',fillstyle='none')
plt.plot(a,0,'o',ms=10,color='r')

# phi
pts = np.array([func(a+1),func(3.5242),func(a+2),0,func(a+5),func(7.9146)])
for k in np.arange(1,7):
    plt.plot(np.linspace(a+k-1+eps,a+k-eps),np.full((50,1),pts[k-1]),'b',linewidth=2), plt.plot(a+k,pts[k-1],'o',ms=10,color='b',fillstyle='right'), plt.plot(a+k-1,pts[k-1],'o',ms=10,color='b',fillstyle='none')
plt.plot(a,func(a+1),'o',ms=10,color='b')
plt.plot(a+2,func(3.5242),'o',ms=10,color='b')
plt.plot(a+6,func(7.9146),'o',ms=10,color='b')

plt.text(1.2,30,r'$\varphi_-$',color='b',fontsize=16)
plt.text(1.67,30,r'$,$',color='black',fontsize=16)
plt.text(1.95,30,r'$f_-,$',color='black',fontsize=16)
plt.text(2.75,30,r'$\psi_-$',color='r',fontsize=16)


#plt.show()
plt.savefig("PosNegFn3.png",bbox_inches='tight')