# Emily J King
# http://www.math.uni-bremen.de/cda/
# This work is licensed under the Creative Commons Attribution-ShareAlike 4.0 In- ternational License. To view a copy of this license, visit http://creativecommons. org/licenses/by-sa/4.0/ or send a letter to Creative Commons, PO Box 1866, Mountain View, CA 94042, USA.

import matplotlib.pyplot as plt
import numpy as np


plt.figure(1)

ax=plt.gca()
ax.grid('off')

def func(x):
    return (x-3)*(x-5)*(x-7)+20

a, b = 2, 9 #limits of integration
x = np.arange(0, 10, 0.01)
y = func(x)
plt.plot(x, y, linewidth=1,color='black')


ax.spines['bottom'].set_bounds(-0.3,10.2)
ax.spines['left'].set_position('zero')
ax.spines['left'].set_bounds(-5,99)
ax.spines['bottom'].set_position('zero')
ax.spines['top'].set_color('none')
ax.spines['right'].set_color('none')
plt.axis([-0.5,10.4, -15, 100])

ax.get_xaxis().tick_bottom()
ax.get_yaxis().tick_left()
ax.set_xticklabels((r'$a$',r'$t_1$',r'$t_2$',r'$t_3$',r'$t_4$',r'$t_5$',r'$t_6$',r'$b$'),fontsize=16,verticalalignment='baseline',y=-10)
ax.set_xticks(np.arange(a,b+1))
ax.yaxis.set_major_locator(plt.NullLocator())


# Plotting step functions
eps=0.12

# phi
pts = np.array([func(a),func(a+1),func(a+3),func(a+4),func((30+4*np.sqrt(3))/6),func(a+5),func(a+6)])
for k in np.arange(1,8):
    plt.plot(np.linspace(a+k-1+eps,a+k-eps),np.full((50,1),pts[k-1]),'b'), plt.plot(a+k,pts[k-1],'o',ms=10,color='b'), plt.plot(a+k-1,pts[k-1],'o',ms=10,color='b',fillstyle='none')
plt.plot(a,func(a),'o',ms=10,color='b')

# psi
pts = np.array([func(a+1),func((30-4*np.sqrt(3))/6),func(a+2),func(a+3),func(a+4),func(a+6),func(a+7)])
for k in np.arange(1,8):
    plt.plot(np.linspace(a+k-1+eps,a+k-eps),np.full((50,1),pts[k-1]),'r'), plt.plot(a+k,pts[k-1],'o',ms=10,color='r'), plt.plot(a+k-1,pts[k-1],'o',ms=10,color='r',fillstyle='none')
plt.plot(a,func(a+1),'o',ms=10,color='r')


plt.text(7.8,90,r'$\varphi$',color='b',fontsize=16)
plt.text(8,90,r'$,$',color='black',fontsize=16)
plt.text(8.25,90,r'$f,$',color='black',fontsize=16)
plt.text(8.75,90,r'$\psi$',color='r',fontsize=16)


plt.show()
#plt.savefig("StepApprox.png",bbox_inches='tight')