# Emily J King
# http://www.math.uni-bremen.de/cda/
# This work is licensed under the Creative Commons Attribution-ShareAlike 4.0 In- ternational License. To view a copy of this license, visit http://creativecommons. org/licenses/by-sa/4.0/ or send a letter to Creative Commons, PO Box 1866, Mountain View, CA 94042, USA.

import matplotlib.pyplot as plt
import numpy as np


plt.figure(1)

ax=plt.gca()
ax.grid('off')

ax.spines['bottom'].set_bounds(-0.1,10.2)
ax.spines['left'].set_position('zero')
ax.spines['left'].set_bounds(-0.1,10.2)
ax.spines['bottom'].set_position('zero')
ax.spines['top'].set_color('none')
ax.spines['right'].set_color('none')
plt.axis([-0.5,10.4, -1.7, 10.4])

a, b = 1, 9 #limits of integration
eps=0.12 # wiggle room for plotting

# Phi
x = np.array([a,2,3,3.5,6.1,6.5,8,b]) # Unterteilung
c = np.array([7,3.5,2,8.1,9.3,4.3,1])

for cnt in np.nditer(np.arange(0,7)):
    plt.plot(np.linspace(x[cnt]+eps,x[cnt+1]-eps),np.full((50,1),c[cnt]),'k',color='blue'), plt.plot(x[cnt],c[cnt],'o',ms=10,color='blue',fillstyle='none'), plt.plot(x[cnt+1],c[cnt],'o',ms=10,color='blue',fillstyle='none')

plt.plot(x,np.array([4,3.5,2,4.2,9.3,6,1,2]),'o',ms=10,color='blue')

plt.text(9.25,8.75,r'$\varphi$',color='blue',fontsize=20)


# Psi
y = np.array([a,4,7,b]) # Unterteilung
d = np.array([5.1,6,2.7])

for cnt in np.nditer(np.arange(0,3)):
    plt.plot(np.linspace(y[cnt]+eps,y[cnt+1]-eps),np.full((50,1),d[cnt]),'k',color='r'), plt.plot(y[cnt],d[cnt],'o',ms=10,color='r',fillstyle='none'), plt.plot(y[cnt+1],d[cnt],'o',ms=10,color='r',fillstyle='none')

plt.plot(y,np.array([5.1,1,2.3,7]),'o',ms=10,color='r')

plt.text(9.75,8.75,r'$\psi$',color='r',fontsize=20)

# Both
ax.get_xaxis().tick_bottom()
ax.get_yaxis().tick_left()
ax.set_xticks((a,2,3,3.5,4,6.1,6.5,7,8,b))
ax.set_xticklabels((r'$a$',r'$x_1$',r'$x_2$',r'$x_3$',r'$y_1$',r'$x_4$',r'$x_5$',r'$y_2$',r'$x_6$',r'$b$'),fontsize=16,verticalalignment='baseline',y=-0.6)
[t.set_color(i) for (i,t) in
 zip(['k','b','b','b','r','b','b','r','b','k'],ax.xaxis.get_ticklabels())]

ax.set_yticks(np.hstack((c,d)))
ax.set_yticklabels((r'$c_1$',r'$c_2$',r'$c_3$',r'$c_4$',r'$c_5$',r'$c_6$',r'$c_7$',r'$d_1$',r'$d_2$',r'$d_3$'),fontsize=16,verticalalignment='top')#,color='blue')
[t.set_color(i) for (i,t) in
 zip(['b','b','b','b','b','b','b','r','r','r'],ax.yaxis.get_ticklabels())]

plt.text(9.5,8.75,r'$,$',color='k',fontsize=20)


# Refinement the partition
yln=np.linspace(0,10,20)
t_label = [r'$t_0$',r'$t_1$',r'$t_2$',r'$t_3$',r'$t_4$',r'$t_5$',r'$t_6$',r'$t_7$',r'$t_8$',r'$t_9$']
t= np.array([a,2,3,3.5,4,6.1,6.5,7,8,b])
for cnt in np.nditer(np.arange(0,t.size)):
    plt.plot(np.full((20,1),t[cnt]),yln,'|',color='g'), plt.text(t[cnt],-1.7,t_label[cnt],color='g',fontsize=16,horizontalalignment='center')


#plt.show()
plt.savefig("StepFn2.png",bbox_inches='tight')