# Emily J King
# http://www.math.uni-bremen.de/cda/
# This work is licensed under the Creative Commons Attribution-ShareAlike 4.0 In- ternational License. To view a copy of this license, visit http://creativecommons. org/licenses/by-sa/4.0/ or send a letter to Creative Commons, PO Box 1866, Mountain View, CA 94042, USA.

import matplotlib.pyplot as plt
import numpy as np


plt.figure(1)

ax=plt.gca()
ax.grid('off')

ax.spines['bottom'].set_bounds(-0.1,10.2)
ax.spines['left'].set_position('zero')
ax.spines['left'].set_bounds(-0.1,10.2)
ax.spines['bottom'].set_position('zero')
ax.spines['top'].set_color('none')
ax.spines['right'].set_color('none')
plt.axis([-0.5,10.4, -2.3, 10.4])

a, b = 1, 9 #limits of integration
eps=0.12 # wiggle room for plotting

# Phi
x = np.array([a,2,3,6.1,7.5,8,b])
y = np.array([a,1.5,5.3,6.1,6.8,7.5,b])
t= np.array([a,1.5,2,3,5.3,6.1,6.8,7.5,8,b])
c = np.array([7,7,7,7,7,1.5,1.5,5.1,5.1])

for cnt in np.nditer(np.arange(0,9)):
    plt.plot(np.linspace(t[cnt],t[cnt+1]),np.full((50,1),c[cnt]),'k',color='k')

plt.plot(a,7,'o',ms=10,color='k')
plt.plot(6.1,7,'o',ms=10,color='k')
plt.plot(6.1,1.5,'o',ms=10,color='k',markerfacecolor='white')
plt.plot(7.5,1.5,'o',ms=10,color='k',markerfacecolor='white')
plt.plot(7.5,5.1,'o',ms=10,color='k')
plt.plot(b,5.1,'o',ms=10,color='k')

plt.text(9.25,8.75,r'$\varphi$',color='k',fontsize=20)


# Labeling axes
ax.get_xaxis().tick_bottom()
ax.get_yaxis().tick_left()
ax.set_xticks(t)
ax.set_xticklabels(())
yln=np.linspace(0,10,20)
t_label = [r'$t_0$',r'$t_1$',r'$t_2$',r'$t_3$',r'$t_4$',r'$t_5$',r'$t_6$',r'$t_7$',r'$t_8$',r'$t_9$']
for cnt in np.nditer(np.arange(0,t.size)):
    plt.text(t[cnt],-2.3,t_label[cnt],color='g',fontsize=16,horizontalalignment='center'), plt.plot(np.full((20,1),t[cnt]),yln,'|',color='g')
y_label = [r'$y_0$',r'$y_1$',r'$y_2$',r'$y_3$',r'$y_4$',r'$y_5$',r'$y_6$']
for cnt in np.nditer(np.arange(0,y.size)):
    plt.text(y[cnt],-1.5,y_label[cnt],color='r',fontsize=16,horizontalalignment='center')
x_label = [r'$x_0$',r'$x_1$',r'$x_2$',r'$x_3$',r'$x_4$',r'$x_5$',r'$x_6$']
for cnt in np.nditer(np.arange(0,x.size)):
    plt.text(x[cnt],-0.7,x_label[cnt],color='b',fontsize=16,horizontalalignment='center')

ax.set_yticks((7,1.5,5.1))
ax.set_yticklabels((r'$\alpha$',r'$\beta$',r'$\gamma$'),fontsize=16,verticalalignment='top')

#plt.show()
plt.savefig("StepFn3.png",bbox_inches='tight')