# Emily J King
# http://www.math.uni-bremen.de/cda/
# This work is licensed under the Creative Commons Attribution-ShareAlike 4.0 In- ternational License. To view a copy of this license, visit http://creativecommons. org/licenses/by-sa/4.0/ or send a letter to Creative Commons, PO Box 1866, Mountain View, CA 94042, USA.

import matplotlib.pyplot as plt
import numpy as np

# set up the figure
plt.figure(1)
ax=plt.gca()

ax.spines['left'].set_position(('data', 0))
ax.spines['bottom'].set_bounds(-0.05,0.65)
ax.spines['right'].set_color('none')
ax.spines['bottom'].set_position(('data', 0))
ax.spines['top'].set_color('none')
ax.spines['left'].set_bounds(-3,22)
ax.xaxis.set_ticks_position('bottom')
ax.yaxis.set_ticks_position('left')

ax.grid('on')

plt.xlim(-0.05,0.65)
plt.ylim(-3,22)


# plot function
x=np.linspace(0.001,1.1,1000)
def f(t): return 1/t

plt.plot(x,f(x),'k',color='black')

# plot eps-del regions
eps = 1

c=17
l = plt.axhline(y=c+eps,linestyle='dashed',color='r')
l = plt.axhline(y=c-eps,linestyle='dashed',color='r')
l = plt.axhline(y=c,linestyle='dashed',color='blue')
ax.fill_between(x,c-eps,c+eps,color='r',alpha=0.3)

plt.text(-0.02,c+0.1,r'$\epsilon$',color='r',fontsize=16)
plt.text(-0.02,c-1,r'$\epsilon$',color='r',fontsize=16)

l = plt.axvline(x=1/(c+eps),linestyle='dashed',color='g')
l = plt.axvline(x=1/c + (1/c - 1/(c+eps)),linestyle='dashed',color='g')
l = plt.axvline(x=1/(c-eps),linestyle='dashed',color='g')
l = plt.axvline(x=1/c,linestyle='dashed',color='blue')

ax.axvspan(1/(c+eps), 1/c + (1/c - 1/(c+eps)), alpha=0.3, color='g')

ax.annotate(r'$\delta_1$', xy=(0.06, -2.7), xytext=(0.12, -3),fontsize=16,color='g',arrowprops=dict(facecolor='g', arrowstyle="-|>"),)
ax.annotate(r'$\delta_1$', xy=(0.06, -2.7), xytext=(0.01, -3),fontsize=16,color='g',arrowprops=dict(facecolor='g', arrowstyle="-|>"),)

c=3
l = plt.axhline(y=c+eps,linestyle='dashed',color='r')
l = plt.axhline(y=c-eps,linestyle='dashed',color='r')
l = plt.axhline(y=c,linestyle='dashed',color='blue')
ax.fill_between(x,c-eps,c+eps,color='r',alpha=0.3)

plt.text(-0.02,c+0.1,r'$\epsilon$',color='r',fontsize=16)
plt.text(-0.02,c-1,r'$\epsilon$',color='r',fontsize=16)

l = plt.axvline(x=1/(c+eps),linestyle='dashed',color='g')
l = plt.axvline(x=1/c + (1/c - 1/(c+eps)),linestyle='dashed',color='g')
l = plt.axvline(x=1/(c-eps),linestyle='dashed',color='g')
l = plt.axvline(x=1/c,linestyle='dashed',color='blue')

ax.axvspan(1/(c+eps), 1/c + (1/c - 1/(c+eps)), alpha=0.3, color='g')

plt.text(1/c - 0.5*(1/c - 1/(c+eps)),-3,r'$\delta_2$',color='g',fontsize=16)
plt.text(1/c + 0.4*(1/c - 1/(c+eps)),-3,r'$\delta_2$',color='g',fontsize=16)

#plt.show()
plt.savefig("UniformCont.png",bbox_inches='tight')