# Emily J King
# http://www.math.uni-bremen.de/cda/
# This work is licensed under the Creative Commons Attribution-ShareAlike 4.0 In- ternational License. To view a copy of this license, visit http://creativecommons. org/licenses/by-sa/4.0/ or send a letter to Creative Commons, PO Box 1866, Mountain View, CA 94042, USA.

import matplotlib.pyplot as plt
import numpy as np

plt.rc('text', usetex=True)
plt.rcParams['text.latex.preamble'] = [r'\boldmath']

# set up the figure
plt.figure(1)
ax=plt.gca()

ax.spines['top'].set_color('none')
ax.spines['right'].set_color('none')

ax.spines['left'].set_position('zero')
ax.set_ylim(-0.05,np.pi+0.05)

ax.spines['bottom'].set_position('zero')
ax.set_xlim(-1.1,1.1)
ax.xaxis.set_ticks_position('bottom')
ax.yaxis.set_ticks_position('left')

ax.patch.set_alpha(0.0)
ax.set_yticks((np.arange(0,5*np.pi/4,np.pi/4)))
ax.set_yticklabels((r'$0$',r'$\frac{\pi}{4}$',r'$\frac{\pi}{2}$',r'$\frac{3\pi}{4}$',r'$\pi$',),size='large',y=-.05)
ax.grid('off')

# plot function
x=np.linspace(-1,1,1000)
y=np.arccos(x)

plt.plot(x,y,'k')

plt.text(0.25,2.5,r'$\arccos(x)$',fontsize=24)

# draw endpoints
plt.plot(1,0,'o',ms=10,c='black')
plt.plot(-1,np.pi,'o',ms=10,c='black')

#plt.show()
plt.savefig("arccos.png",bbox_inches='tight')