# Emily J King
# http://www.math.uni-bremen.de/cda/
# This work is licensed under the Creative Commons Attribution-ShareAlike 4.0 In- ternational License. To view a copy of this license, visit http://creativecommons. org/licenses/by-sa/4.0/ or send a letter to Creative Commons, PO Box 1866, Mountain View, CA 94042, USA.

import matplotlib.pyplot as plt
import numpy as np

plt.rc('text', usetex=True)
plt.rcParams['text.latex.preamble'] = [r'\boldmath']

# set up the figure
plt.figure(1)
ax=plt.gca()

ax.spines['top'].set_color('none')
ax.spines['right'].set_color('none')
ax.spines['left'].set_position('zero')
ax.spines['left'].set_bounds(-1.1,1.1)
ax.spines['bottom'].set_position('zero')
ax.set_xlim(-4,4)
ax.xaxis.set_ticks_position('bottom')
ax.yaxis.set_ticks_position('left')

ax.patch.set_alpha(0.0)
ax.set_xticks((np.arange(-5*np.pi/4,6*np.pi/4,np.pi/4)))
ax.set_xticklabels((r'$-\frac{5\pi}{4}$',r'$-\pi$',r'$-\frac{3\pi}{4}$',r'$-\frac{\pi}{2}$',r'$-\frac{\pi}{4}$',r'$0$',r'$\frac{\pi}{4}$',r'$\frac{\pi}{2}$',r'$\frac{3\pi}{4}$',r'$\pi$',r'$\frac{5\pi}{4}$'),size='large',y=-.05)

ax.grid('off')

plt.ylim(-20,20)

# plot function
x=np.linspace(-4,-np.pi/2-0.001,1000)
y=np.tan(x)
plt.plot(x,y,'k')

x=np.linspace(-np.pi/2+0.001,np.pi/2-0.001,1000)
y=np.tan(x)
plt.plot(x,y,'k')

x=np.linspace(np.pi/2+0.001,4,1000)
y=np.tan(x)
plt.plot(x,y,'k')

plt.text(2.3,16,r'$\tan(x)$',fontsize=24)

# draw asymptotes
y=np.linspace(-20,20,20)
plt.plot(np.full((20,1),np.pi/2),y,'|',color='black')
plt.plot(np.full((20,1),-np.pi/2),y,'|',color='black')

#plt.show()
plt.savefig("tan.png",bbox_inches='tight')